@@ -7,6 +7,9 @@ import errno
 
 
 def is_root(ctx, param, value):
+    if not value:
+        ctx.abort()
+
     if os.geteuid() == 0:
         return True
     else:
@@ -52,7 +55,7 @@ def update_config_file(new_config):
 
 
 @click.command()
-@click.option('--yes', is_flag=True, callback=is_root, expose_value=True, prompt='Are you running command from root?')
+@click.option('--yes', is_flag=True, callback=is_root, expose_value=False, prompt='Are you running command from root?')
 @click.option("--monitoring-system", prompt="Choose monitoring system to configure", help="Monitoring system", type=click.Choice(['zabbix', 'icinga'], case_sensitive=False), required=True)
 @click.option("--integration-name", prompt="Choose unique name of your integration", help="Name of your integration", required=True)
 @click.option("--url", prompt="URL to your system (http://system-hostname)", help="http://system-hostname", required=True, callback=validate_url)
